#include <iostream>
#include <vector>
#include <random>
#include <algorithm>

const int kSeed = 568493;

std::mt19937 gen(kSeed);

bool CountIncorrect(const std::vector<int> &a,
                    const std::vector<int> &q) {
    int count = 0;
    for (int i = 0; i < a.size(); ++i) {
        if (q[i] == i || a[q[i]] == i) {
            count++;
        }
    }
    return count;
}

void Generate(std::vector<int> &q) {
    int n = static_cast<int>(q.size());
    for (int i = 0; i < n; ++i) {
        q[i] = i;
    }
    std::shuffle(q.begin(), q.end(), gen);
}

int main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    std::cout.tie(nullptr);

    int t;
    std::cin >> t;
    while (t--) {
        int n;
        std::cin >> n;
        std::vector<int> a(n);
        for (int &x: a) {
            std::cin >> x;
            x--;
        }

        std::vector<int> q(n);
        int best_cnt = n + 1;
        std::vector<int> best(n);
        for (int k = 0; k < 200; ++k) {
            Generate(q);
            int count = CountIncorrect(a, q);
            if (count < best_cnt) {
                best_cnt = count;
                best.swap(q);
            }

            if (best_cnt == 0) {
                break;
            }
        }

        q = best;

        if (best_cnt > 0) {
            int tries = 10'000'000 / best_cnt;

            std::uniform_int_distribution<int> random(0, n - 1);
            for (int i = 0; i < n; ++i) {
                if (q[i] == i || a[q[i]] == i) {
                    int target;
                    for (int j = 0; j < tries; ++j) {
                        target = random(gen);
                        if (target == i) {
                            continue;
                        }
                        if (q[target] == i || a[q[target]] == i || q[i] == target || a[q[i]] == target) {
                            continue;
                        }
                        std::swap(q[i], q[target]);
                    }
                }
            }
        }

        best_cnt = CountIncorrect(a, q);
        if (best_cnt > 0) {
            std::cout << "Impossible\n";
        } else {
            std::cout << "Possible\n";
            std::vector<int> inv_q(n);
            for (int i = 0; i < n; ++i) {
                inv_q[q[i]] = i;
            }
            std::vector<int> p(n);
            for (int i = 0; i < n; ++i) {
                p[q[a[i]]] = i;
            }
            for (int i = 0; i < n; ++i) {
                std::cout << p[i] + 1 << " ";
            }
            std::cout << "\n";
            for (int i = 0; i < n; ++i) {
                std::cout << q[i] + 1 << " ";
            }
            std::cout << "\n";
        }
    }

    return 0;
}
